@@ -6,6 +6,7 @@ from gnosis.safe.safe_tx import SafeTx
 from eth_abi import encode_abi
 from typing import Optional, Union
 from brownie.network.account import LocalAccount
+from brownie._config import CONFIG
 
 # CI horribleness lurks below
 # If running in CI, let's override ApeSafe.post_transaction so
@@ -81,7 +82,7 @@ class DelegateSafe(ApeSafe):
 
         if self.is_ci and self.is_send:
             if "{1}" in self.frontend_url:
-                formatted_frontend_url = self.frontend_url.format(self.address, safe_tx.safe_tx_hash)
+                formatted_frontend_url = self.frontend_url.format(self.address, safe_tx.safe_tx_hash.hex())
             else:
                 formatted_frontend_url = self.frontend_url.format(self.address)
 
@@ -164,5 +165,8 @@ class DelegateSafe(ApeSafe):
         
         return super().sign_transaction(safe_tx, signer)
 
-with open(os.path.join(home_directory, "alive.signal"), "w") as f:
-    f.write("I am alive")
+if os.environ.get("CI", "").lower() == "true":
+    with open(os.path.join(home_directory, "alive.signal"), "w") as f:
+        f.write("I am alive")
+
+    CONFIG.settings["console"]["show_colors"] = False
